
*****************
amethyst.core.obj
*****************

.. currentmodule:: amethyst.core.obj
.. autosummary::

     Object
     Attr
     amethyst_deflate
     amethyst_inflate
     register_amethyst_type


.. automodule:: amethyst.core.obj
   :members:
   :special-members:
   :exclude-members: __dict__,__weakref__,__module__
